Home - Federal Business Opportunities: Home

# Accessibility Information

Users of assistive technologies such as screen readers should use the following link to activate Accessibility Mode before continuing: Learn more and Activate accessibility mode.

- Skip to content
- tabs
- main menu
- Accessibility Mode

# Federal Business Opportunities

- IAE
- eGov
- USA.gov

# Search more than 25,400* federal opportunities.

Posted Date:
Set-Aside Code:
Place of Performance:
Type:
Keyword / Solicitation #:
Agency: Click and begin typing to initiate search
Additional criteria and multiple selections are available on the advanced search form.
* Notices posted within the last 90 days.

ATTENTION: Agency users are responsible for properly uploading controlled, unclassified materials to FBO using the access control procedures for document packages and attachments detailed in the FBO Buyers Guide. Do not upload ANY classified materials to FBO.

Important Cyber Security Notice - October is CYBER SECURITY AWARENESS month! Choose a unique and strong username and password. Do not share your password and always log off when you step away --- it only takes a moment for someone to steal or change the password.

Security Information - For an important notice about recent cybersecurity incidents that may impact Federal employees and contractors, please visit www.opm.gov and http://www.archives.gov/isoo/notices/.

Important Password Update - Mandatory reset of passwords is required every 90 days. Registered users will receive an email notification to remind them of this requirement.
If your account has been disabled, contact the Federal Service Desk at 866-606-8220 (Monday - Friday 8 a.m. to 8 p.m. ET)

## Buyers / Engineers

Government users may post, manage, and award opportunities.

Buyer / Engineer Username
Buyer / Engineer Password

- View Opportunities

  No login is required to view opportunities.

- Register Now
- Password Reminder
- Recovery FAQs

## Vendors / Citizens

Vendors and citizens may search, monitor, and retrieve opportunities.

Vendor / Citizen Username
Vendor / Citizen Password

- Find Opportunities

  No login is required to view opportunities.

- Register Now
- Password Reminder
- Recovery FAQs

- FBO now contains Recovery and Reinvestment Act actions. Search Recovery Act Opportunities
- FBO now contains Recovery and Reinvestment Act actions. Search Recovery Act Awards

## FBO Recovery Reports

- Click here for Opportunities
- Click here for Awards

Learn more about FBO recovery reports.

## Small Business Events

Learn more about the Small Business Central Event Listing or search now for events.

- Search Small Business Events.

## Vendor Collaboration

FBO now contains the Vendor Collaboration Central Event Listing. Learn more or search.

- Vendor Opportunities

## User Guides

- Buyer
- Vendor
- Engineer
- Location / Agency Admin

Use Adobe Acrobat Reader to view files in PDF format.

## Demonstration Videos

Learn about FBO features and functionality in on-line videos.

Watch the Videos

## Location / Agency Administrators

- Login Here
- Register Now

## Additional Resources

- FAQs
- Federal Service Desk
- Procurement Technical Assistance Program (PTAC)
- Recovery.gov
- Whitehouse.gov/recovery/
- System for Award Management (SAM)

- Federal Agency Business Forecasts
- Federal Assets Sales
- Federal Grants
- USA.gov
- Minority Business Development Agency
- SUB - Net (Subcontracting Opportunities)
- IAE

- For Help: Federal Service Desk
- Accessibility